import { useEffect, useRef, useState } from 'react';
import { React, type AllWidgetProps } from 'jimu-core'
import { type IMConfig } from '../config'
import WidgetView from './WidgetView';

/*
 * Copyright (c) 2018-2024, Orbit Geospatial Technologies. All rights reserved.
 * Use is subject to license terms.
 */

/**
 * Loads the Orbit SDK dependency and then goes on creating the actual WidgetView.
 */
const Widget = (props: AllWidgetProps<IMConfig>) => {

	const [sdk,setSDK] = useState();

	useEffect(() => {
		// The orbit library uses the dojo-provided 'provide' function to register.
		// So we need to use the dojo-provided 'require' to instantiate the library.
		type DojoRequire = (list: string[], callback: (value: any) => void) => void;
		const dojoRequire: DojoRequire = window["require"] as any;
		let url = "https://cdn.3dmapping.cloud/stable/javascript/viewer_sdk_javascript.js";
		dojoRequire([url], (orbitgt) => {
			setSDK(orbitgt);
		});
	},[]); // deps never change, so runs only once.

	if (sdk==null) {
		return <span>Loading SDK...</span>;
	} else {
		return <WidgetView widgetProps={props} orbitgt={sdk}/>
	}
}

export default Widget
